Corporate Analyzer
Date: 08 27, 2001 2:28:25 PM

# Corporate Analyzer Tour

The tour of the Corporate Analyzer (in the VisualText\apps folder) is intended to take you through the step by step process used in building the Corporate Analyzer. It will give you an idea of the approach and techniques used to build analyzers. This tour is a supplement to the VisualText Quick Tour. Study of the tutorials is also recommended for a more complete understanding of this tour.

We recommend you run the Corporate Analyzer application as you go through the tour. This will give you an opportunity to see how the analyzer works as you read through the discussion.

Tour the Corporate Analyzer.